==> jc-1.4.0.tar.gz: gnu/java/io/ClassLoaderObjectInputStream.h <==
// public class gnu.java.io.ClassLoaderObjectInputStream

// class file dependencies
// @dep_class da7221f71e109c05 gnu_java_io_ClassLoaderObjectInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 4008cd22e279a8c3 java_io_ObjectInputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_ObjectInputStream

#include "java/io/ObjectInputStream.h"

#ifndef _JC_gnu_java_io_ClassLoaderObjectInputStream_H_
#define _JC_gnu_java_io_ClassLoaderObjectInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_refs	_jc_gnu_java_io_ClassLoaderObjectInputStream$sub_refs;
typedef struct _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_nonrefs	_jc_gnu_java_io_ClassLoaderObjectInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_io_ClassLoaderObjectInputStream$refs	_jc_gnu_java_io_ClassLoaderObjectInputStream$refs;
typedef struct _jc_gnu_java_io_ClassLoaderObjectInputStream$nonrefs	_jc_gnu_java_io_ClassLoaderObjectInputStream$nonrefs;
typedef struct _jc_gnu_java_io_ClassLoaderObjectInputStream$object	_jc_gnu_java_io_ClassLoaderObjectInputStream$object;

typedef const struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vmethods	_jc_gnu_java_io_ClassLoaderObjectInputStream$vmethods;
typedef const struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vtable	_jc_gnu_java_io_ClassLoaderObjectInputStream$vtable;
typedef const struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vtype	_jc_gnu_java_io_ClassLoaderObjectInputStream$vtype;

// Constructors
extern void _jc_gnu_java_io_ClassLoaderObjectInputStream$method$_init$e906666ccc78acdf(_jc_env *, struct _jc_gnu_java_io_ClassLoaderObjectInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_io_ClassLoaderObjectInputStream$method$resolveClass$315dc045312e3852(_jc_env *, struct _jc_gnu_java_io_ClassLoaderObjectInputStream$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_io_ClassLoaderObjectInputStream$method_info$resolveClass$315dc045312e3852;

// Virtual methods structure
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vmethods {
	struct _jc_java_lang_Class$object	*(*resolveClass$315dc045312e3852)(_jc_env *, struct _jc_gnu_java_io_ClassLoaderObjectInputStream$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_ObjectInputStream$vmethods	java_io_ObjectInputStream;
	_jc_gnu_java_io_ClassLoaderObjectInputStream$vmethods	gnu_java_io_ClassLoaderObjectInputStream;
};

// Vtype
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_io_ClassLoaderObjectInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_refs {
	struct _jc_java_lang_ClassLoader$object	*myClassLoader;
};

// Reference instance fields (object)
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$refs {
    _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_refs	gnu_java_io_ClassLoaderObjectInputStream;
    _jc_java_io_ObjectInputStream$sub_refs	java_io_ObjectInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_ObjectInputStream$sub_nonrefs	java_io_ObjectInputStream;
    _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_nonrefs	gnu_java_io_ClassLoaderObjectInputStream;
};

// Object instance structure
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$object {
	_jc_gnu_java_io_ClassLoaderObjectInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_ClassLoaderObjectInputStream$vtype	*vtype;
	_jc_gnu_java_io_ClassLoaderObjectInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_ClassLoaderObjectInputStream$vtype _jc_gnu_java_io_ClassLoaderObjectInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_ClassLoaderObjectInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_ClassLoaderObjectInputStream$class_object;

#endif	/* _JC_gnu_java_io_ClassLoaderObjectInputStream_H_ */

==> jc-1.4.5.tar.gz: gnu/java/io/ClassLoaderObjectInputStream.h <==
// public class gnu.java.io.ClassLoaderObjectInputStream

// class file dependencies
// @dep_class da7221f71e109c05 gnu_java_io_ClassLoaderObjectInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class d8257ba70d6d4735 java_io_ObjectInputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_ObjectInputStream

#include "java/io/ObjectInputStream.h"

#ifndef _JC_gnu_java_io_ClassLoaderObjectInputStream_H_
#define _JC_gnu_java_io_ClassLoaderObjectInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_refs	_jc_gnu_java_io_ClassLoaderObjectInputStream$sub_refs;
typedef struct _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_nonrefs	_jc_gnu_java_io_ClassLoaderObjectInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_io_ClassLoaderObjectInputStream$refs	_jc_gnu_java_io_ClassLoaderObjectInputStream$refs;
typedef struct _jc_gnu_java_io_ClassLoaderObjectInputStream$nonrefs	_jc_gnu_java_io_ClassLoaderObjectInputStream$nonrefs;
typedef struct _jc_gnu_java_io_ClassLoaderObjectInputStream$object	_jc_gnu_java_io_ClassLoaderObjectInputStream$object;

typedef const struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vmethods	_jc_gnu_java_io_ClassLoaderObjectInputStream$vmethods;
typedef const struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vtable	_jc_gnu_java_io_ClassLoaderObjectInputStream$vtable;
typedef const struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vtype	_jc_gnu_java_io_ClassLoaderObjectInputStream$vtype;

// Constructors
extern void _jc_gnu_java_io_ClassLoaderObjectInputStream$method$_init$e906666ccc78acdf(_jc_env *, struct _jc_gnu_java_io_ClassLoaderObjectInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_io_ClassLoaderObjectInputStream$method$resolveClass$315dc045312e3852(_jc_env *, struct _jc_gnu_java_io_ClassLoaderObjectInputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_io_ClassLoaderObjectInputStream$method_info$resolveClass$315dc045312e3852;

// Virtual methods structure
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vmethods {
	struct _jc_java_lang_Class$object	*(*resolveClass$315dc045312e3852)(_jc_env *, struct _jc_gnu_java_io_ClassLoaderObjectInputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_ObjectInputStream$vmethods	java_io_ObjectInputStream;
	_jc_gnu_java_io_ClassLoaderObjectInputStream$vmethods	gnu_java_io_ClassLoaderObjectInputStream;
};

// Vtype
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_io_ClassLoaderObjectInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_refs {
	struct _jc_java_lang_ClassLoader$object	*myClassLoader;
};

// Reference instance fields (object)
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$refs {
    _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_refs	gnu_java_io_ClassLoaderObjectInputStream;
    _jc_java_io_ObjectInputStream$sub_refs	java_io_ObjectInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_ObjectInputStream$sub_nonrefs	java_io_ObjectInputStream;
    _jc_gnu_java_io_ClassLoaderObjectInputStream$sub_nonrefs	gnu_java_io_ClassLoaderObjectInputStream;
};

// Object instance structure
struct _jc_gnu_java_io_ClassLoaderObjectInputStream$object {
	_jc_gnu_java_io_ClassLoaderObjectInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_ClassLoaderObjectInputStream$vtype	*vtype;
	_jc_gnu_java_io_ClassLoaderObjectInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_ClassLoaderObjectInputStream$vtype _jc_gnu_java_io_ClassLoaderObjectInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_ClassLoaderObjectInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_ClassLoaderObjectInputStream$class_object;

#endif	/* _JC_gnu_java_io_ClassLoaderObjectInputStream_H_ */
